# Weighted Olympic Medal Counts
# Interactive Visualization
# R Shiny User Interface
#
# Christopher Adolph
# 27 February 2023   faculty.washington.edu/cadolph

## Shiny UI
library(shinyjs)
library(shinycssloaders)

shinyUI(fluidPage(

    
    ## Example of CSS control within the UI script
    tags$head(tags$style(HTML("
      @import url('//fonts.googleapis.com/css?family=Libre+Baskerville:400');
      @import url('//fonts.googleapis.com/css?family=Montserrat');
      @import url('//fonts.googleapis.com/css?family=Inconsolata');

      body { word-wrap: break-word; }

      h1 {font-family: 'Libre Baskerville', serif;
         font-size: 125%;
         line-height: 1.3;
         color: #97a786;
      }

      h2 {font-family: 'Libre Baskerville', serif;
         font-size: 115%;
         line-height: 1.3;
         color: #97a786;
      }

      p {
        font-family: 'Montserrat', serif;
        font-size: 100%;
        line-height: 1.35;
        color: #004657;
      }

      #myImage{
        margin-top: -50px;
        margin-left: -30px;
      }

      #caption{font-family: 'Libre Baskerville', serif;
        font-size: 110%;
        line-height: 1.65;        
        padding-left: 45px;
        padding-right: 15px;
      }

      #explanation{font-family: 'Libre Baskerville', serif;
        font-size: 115%;
        line-height: 1.65;        
        padding-left: 20px;
        padding-right: 25px;
      }

      #toc_container {
        background: none repeat scroll 0 0;
        display: table;
        font-size: 95%;
        margin-bottom: 1em;
        padding: 20px;
        width: auto;
      }

      .toc_title {
        font-weight: 700;
        padding:20px;
      }

      #toc_container li, #toc_container ul, #toc_container ul li{
        list-style: outside none none !important;
      }

    "))
    ),

    ##tags$head(includeScript("google-analytics.js")),

    tags$head(HTML(sprintf("<!-- Global site tag (gtag.js) - Google Analytics -->
<script async src='https://www.googletagmanager.com/gtag/js?id=UA-25981482-2'></script>
<script>
  window.dataLayer = window.dataLayer || [];
  function gtag(){dataLayer.push(arguments);}
  gtag('js', new Date());

  gtag('config', 'UA-25981482-2');
</script>
"))),
    
    

    
##    fluidRow(column(width=12,
##                 )),
    
    fluidRow(
     column(width=12, class = "col-md-3",
         h1(HTML("Who&rsquo;s Winning the Olympics?")),   
            
         p(HTML("The country with the most total medals or the one with the most gold medals?")),

         p(HTML("These popular answers are too rigid.")),

         p(HTML("Everyone can agree silver should never be worth more than gold, and bronze never more than silver.  All the weights that satisfy these rules are shown as blocks at the right.")),

         p(HTML("The curve marks good solutions:</br><em>Geometric weights</em> assign the same proportional reduction for dropping from gold to silver as for silver to bronze.")),

         p(HTML("The circle marks the best answer:</br><em>Goldilocks weights</em> value a lower medal half as much as the next medal up.")), 

         p(HTML("<p style='line-height:0.2'></br></p>")),
         
         p(HTML("Graphic and text by <a href='http://chrisadolph.com'>Christopher Adolph</a>. First publication: 12 February 2018. Historical data drawn from <a href='https://en.wikipedia.org/wiki/Category:Olympic_Games_medal_tables'>Wikipedia</a>.")),

         p(HTML("<p style='line-height:0.2'></br></p>")),
         
        ## To add:  choose sport, all years option


         useShinyjs(),
         hidden(checkboxInput("annotate", "Show geometric and goldilocks weights", TRUE)),

         hidden(radioButtons("olympics", "Choose Olympics",
                      c("Summer" = "summer",
                        "Winter" = "winter"
                        ),
                      selected = "winter",
                      inline = TRUE
                      )),

         p(HTML("<p style='line-height:0.2'></br></p>")),
         
         ##radioButtons("period", "Choose Time Period",
         ##             c("Specific Year" = "year",
         ##               "All Years" = "all"
         ##               ),
         ##             inline = TRUE
         ##             ),
         
         conditionalPanel(
             condition = "(input.olympics == 'summer')",
             ##condition = "(input.olympics == 'summer')&&(input.period == 'year')",
             sliderInput("yearS", "Compare past Summer Olympiads",
                     min=27, max=30, value=30, step=1, sep="")  
         ),

         conditionalPanel(
             condition = "(input.olympics == 'winter')",
             ##condition = "(input.olympics == 'winter')&&(input.period == 'year')",
             sliderInput("yearW", "Compare the 2022 Winter Games in Beijing to past Winter Games",
                     min=1, max=24, value=24, step=1, sep="")
         ),         

         conditionalPanel(
             condition = "input.period == 'all'",
             radioButtons("geometric", "Allow geometric weight k to vary?",
                          c("Show winning country for each k" = "allK",
                            "Show ranked countries for a specific k" = "specificK"
                            ),
                          inline = FALSE
                          )
         ),

         conditionalPanel(
             condition = "(input.period == 'all')&&(input.geometric == 'specificK')",
             sliderInput("chooseK", "Choose geometric weight k",
                     min=0, max=1, value=0.5, step=0.05)
         ),  
         
         conditionalPanel(
             condition = "input.geometric != 'specificK'",
             selectizeInput("excluded", "Remove one or more leaders to reveal the race for 2nd place, 3rd place, and so on",
                            choices = NULL, multiple = TRUE,
                            options = list(maxOptions = 5,
                                placeholder = "Type & select a 3-letter country code"))
         ),

         ## Remove Russia from 2014 Winter Olympics by default
         hidden(conditionalPanel(
             condition = "(input.geometric != 'specificK')",
             selectizeInput("disqualified", "Disqualify Countries",
                            choices = NULL, multiple = TRUE,
                            options = list(maxOptions = 5,
                                placeholder = "Enter a 3-letter country code(s) to disqualify"))
         )),

         p(HTML("<p style='line-height:0.2'></br></p>")),
         
         conditionalPanel(
             condition = "(input.yearW == 22)",
             checkboxInput("disqualifyRUS", "Disqualify Russia?", value = TRUE)
         )##,
         
        # Add check box to disqualify Russia conditionally
         
         #conditionalPanel(
         #    condition = "(input.geometric != 'specificK')&&(input.olympics == 'winter')&&(input.yearW==22)",
         #    selectizeInput("disqualified", "Disqualify Countries",
         #                   choices = NULL, multiple = TRUE,
         #                   options = list(maxOptions = 5,
         #                       placeholder = "Type RUS for results after Russia is DQ'ed"))
         #),

         #conditionalPanel(
         #    condition = "(input.geometric != 'specificK')&&((input.olympics == 'summer')||((input.olympics == 'winter')&&(input.yearW!=22)))",
         #    selectizeInput("disqualified", "Disqualify Countries",
         #                   choices = NULL, multiple = TRUE,
         #                   options = list(maxOptions = 5,
         #                       placeholder = "Enter 3-letter country code(s) to delete"))
         #)

         #p(HTML("<p style='line-height:0.4'></br></p>")),
         #p(HTML("Christopher Adolph </br> <a href='http://www.chrisadolph.com'>chrisadolph.com</a>"))
         
         ),
    
     column(width=12, class = "col-md-9",
            tabsetPanel(
                tabPanel(title = "Explore Different Weights",
                         fluidRow(
                             column(width = 12,  class = "col-md-8",
                                    ## Use imageOutput to place the image on the page
                                    p(HTML("</br></br></br>")),
                                    withSpinner(imageOutput("myImage", width="auto", height="auto"))
                                    ##width="auto", height="auto")#height = "789px")
                                    ),
                             
                             column(width=12, class = "col-md-4",
                                    p(HTML("</br>")),
                                    p(htmlOutput("caption"))
                                    ))),

                tabPanel(title = "A Better Medals Table",
                         fluidRow(
                             column(width = 12, class = "col-md-11",
                                    p(HTML("</br></br>")),
                                    
                                    h1(htmlOutput("tableTitle")),

                                    p(HTML("Click any column header to sort by that column.  <em>Rank</em> is based on Goldilocks score, which awards four points for each gold medal, two points for each silver, and one point for each bronze.  Countries with the same goldilocks score are ordered by total golds as a tiebreaker, and total medals as a second tiebreaker.</br></br>")),
                                    
                                    withSpinner(DT::dataTableOutput("medalTable"))
                                    )
                         )),
                tabPanel(title = "Why Weighted Medal Tallies?",
                         fluidRow(
                             column(width = 12,  class = "col-md-9",

                                    p(HTML("</br>")),
                                    withSpinner(p(htmlOutput("explanation")))
                                    
                                    )))
            ))    
     )
  )
)


